@@ -2,6 +2,7 @@ from typing import List
 from typing import Any
 
 from dataclasses import dataclass
+from collections import OrderedDict
 
 
 @dataclass
@@ -12,7 +13,7 @@ class Summary:
     payments: str
 
     @staticmethod
-    def from_dict(obj: dict) -> 'Summary':
+    def from_dict(obj: dict) -> "Summary":
         _credits = str(obj.get("credits"))
         _electricity_used = str(obj.get("electricity_used"))
         _other_charges = str(obj.get("other_charges"))
@@ -29,13 +30,15 @@ class AccountBalanceConnection:
     unbilled_days: int
 
     @staticmethod
-    def from_dict(obj: Any) -> 'AccountBalanceConnection':
+    def from_dict(obj: Any) -> "AccountBalanceConnection":
         _hop_percentage = str(obj.get("hop_percentage"))
         _id = int(obj.get("id"))
         _running_balance = str(obj.get("running_balance"))
         _start_date = str(obj.get("start_date"))
         _unbilled_days = int(obj.get("unbilled_days"))
-        return AccountBalanceConnection(_hop_percentage, _id, _running_balance, _start_date, _unbilled_days)
+        return AccountBalanceConnection(
+            _hop_percentage, _id, _running_balance, _start_date, _unbilled_days
+        )
 
 
 @dataclass
@@ -52,10 +55,13 @@ class AccountBalance:
     type: str
 
     @staticmethod
-    def from_dict(account_balance_data: dict) -> 'AccountBalance':
+    def from_dict(account_balance_data: dict) -> "AccountBalance":
         account_balance = account_balance_data.get("data")
 
-        _connections = [AccountBalanceConnection.from_dict(y) for y in account_balance.get("connections")]
+        _connections = [
+            AccountBalanceConnection.from_dict(y)
+            for y in account_balance.get("connections")
+        ]
         _last_billed_amount = str(account_balance.get("last_billed_amount"))
         _last_billed_date = str(account_balance.get("last_billed_date"))
         _next_billing_date = str(account_balance.get("next_billing_date"))
@@ -65,8 +71,18 @@ class AccountBalance:
         _total_billing_days = int(account_balance.get("total_billing_days"))
         _total_running_balance = str(account_balance.get("total_running_balance"))
         _type = str(account_balance.get("type"))
-        return AccountBalance(_connections, _last_billed_amount, _last_billed_date, _next_billing_date, _is_prepay,
-                              _summary, _total_account_balance, _total_billing_days, _total_running_balance, _type)
+        return AccountBalance(
+            _connections,
+            _last_billed_amount,
+            _last_billed_date,
+            _next_billing_date,
+            _is_prepay,
+            _summary,
+            _total_account_balance,
+            _total_billing_days,
+            _total_running_balance,
+            _type,
+        )
 
 
 @dataclass
@@ -89,7 +105,7 @@ class Customer:
     medically_dependent_customer: str
 
     @staticmethod
-    def from_dict(customer_data: dict) -> 'Customer':
+    def from_dict(customer_data: dict) -> "Customer":
         customer = customer_data.get("data")
 
         _bill_address_1 = str(customer.get("bill_address_1"))
@@ -107,10 +123,27 @@ class Customer:
         _phone_number = str(customer.get("phone_number"))
         _gender = str(customer.get("gender"))
         _is_active = str(customer.get("is_active"))
-        _medically_dependent_customer = str(customer.get("medically_dependent_customer"))
-        return Customer(_bill_address_1, _bill_address_2, _bill_city, _bill_company, _bill_name, _bill_post_code,
-                        _birth_date, _customer_number, _email, _first_name, _last_name, _middle_name, _phone_number,
-                        _gender, _is_active, _medically_dependent_customer)
+        _medically_dependent_customer = str(
+            customer.get("medically_dependent_customer")
+        )
+        return Customer(
+            _bill_address_1,
+            _bill_address_2,
+            _bill_city,
+            _bill_company,
+            _bill_name,
+            _bill_post_code,
+            _birth_date,
+            _customer_number,
+            _email,
+            _first_name,
+            _last_name,
+            _middle_name,
+            _phone_number,
+            _gender,
+            _is_active,
+            _medically_dependent_customer,
+        )
 
 
 @dataclass
@@ -121,7 +154,7 @@ class Hop:
     interval_end: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Hop':
+    def from_dict(obj: Any) -> "Hop":
         _start_time = str(obj.get("start_time"))
         _end_time = str(obj.get("end_time"))
         _interval_start = str(obj.get("interval_start"))
@@ -142,7 +175,7 @@ class CustomerConnection:
     end_date: str
 
     @staticmethod
-    def from_dict(customer_connection_data: Any) -> 'CustomerConnection':
+    def from_dict(customer_connection_data: Any) -> "CustomerConnection":
         customer_connection = customer_connection_data.get("data")
 
         _type = str(customer_connection.get("type"))
@@ -154,8 +187,17 @@ class CustomerConnection:
         _hop = Hop.from_dict(customer_connection.get("hop"))
         _start_date = str(customer_connection.get("start_date"))
         _end_date = str(customer_connection.get("end_date"))
-        return CustomerConnection(_type, _id, _customer_number, _identifier, _address, _is_active, _hop, _start_date,
-                                  _end_date)
+        return CustomerConnection(
+            _type,
+            _id,
+            _customer_number,
+            _identifier,
+            _address,
+            _is_active,
+            _hop,
+            _start_date,
+            _end_date,
+        )
 
 
 @dataclass
@@ -169,7 +211,7 @@ class BillingAddress:
     type: str
 
     @staticmethod
-    def from_dict(billing_address_data: dict) -> 'BillingAddress':
+    def from_dict(billing_address_data: dict) -> "BillingAddress":
         billing_address = billing_address_data.get("data")
 
         _address_1 = str(billing_address.get("address_1"))
@@ -179,7 +221,9 @@ class BillingAddress:
         _name = str(billing_address.get("name"))
         _post_code = str(billing_address.get("post_code"))
         _type = str(billing_address.get("type"))
-        return BillingAddress(_address_1, _address_2, _city, _company, _name, _post_code, _type)
+        return BillingAddress(
+            _address_1, _address_2, _city, _company, _name, _post_code, _type
+        )
 
 
 @dataclass
@@ -191,7 +235,7 @@ class BillingFrequency:
     type: str
 
     @staticmethod
-    def from_dict(billing_frequency_data: dict) -> 'BillingFrequency':
+    def from_dict(billing_frequency_data: dict) -> "BillingFrequency":
         billing_frequency = billing_frequency_data.get("data")
         _billing_date = str(billing_frequency.get("billing_date"))
         _day = str(billing_frequency.get("day"))
@@ -217,7 +261,7 @@ class Bill:
     type: str
 
     @staticmethod
-    def from_dict(bill_data: Any) -> 'Bill':
+    def from_dict(bill_data: Any) -> "Bill":
         bill = bill_data.get("data")
         if bill is None:
             bill = bill_data
@@ -227,15 +271,29 @@ class Bill:
         _end_date = str(bill.get("end_date"))
         _file = str(bill.get("file"))
         _id = int(bill.get("id"))
-        _invoice_total_charges_incl_gst = float(bill.get("invoice_total_charges_incl_gst"))
+        _invoice_total_charges_incl_gst = float(
+            bill.get("invoice_total_charges_incl_gst")
+        )
         _start_date = str(bill.get("start_date"))
         _status = str(bill.get("status"))
         _status_message = str(bill.get("status_message"))
         _title = str(bill.get("title"))
         _total_to_pay = float(bill.get("total_to_pay"))
         _type = str(bill.get("type"))
-        return Bill(_date_to_pay, _date_generated, _end_date, _file, _id, _invoice_total_charges_incl_gst, _start_date,
-                    _status, _status_message, _title, _total_to_pay, _type)
+        return Bill(
+            _date_to_pay,
+            _date_generated,
+            _end_date,
+            _file,
+            _id,
+            _invoice_total_charges_incl_gst,
+            _start_date,
+            _status,
+            _status_message,
+            _title,
+            _total_to_pay,
+            _type,
+        )
 
 
 @dataclass
@@ -247,7 +305,7 @@ class Links:
     self: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Links':
+    def from_dict(obj: Any) -> "Links":
         _first = str(obj.get("first"))
         _last = str(obj.get("last"))
         _next = str(obj.get("next"))
@@ -265,7 +323,7 @@ class Pagination:
     total_count: int
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Pagination':
+    def from_dict(obj: Any) -> "Pagination":
         _limit = int(obj.get("limit"))
         _links = Links.from_dict(obj.get("links"))
         _offset = int(obj.get("offset"))
@@ -279,7 +337,7 @@ class Meta:
     pagination: Pagination
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Meta':
+    def from_dict(obj: Any) -> "Meta":
         _pagination = Pagination.from_dict(obj.get("pagination"))
         return Meta(_pagination)
 
@@ -291,8 +349,8 @@ class Bills:
     type: str
 
     @staticmethod
-    def from_dict(bills_data: dict) -> 'Bills':
-        bills = bills_data.get('data')
+    def from_dict(bills_data: dict) -> "Bills":
+        bills = bills_data.get("data")
 
         _bills = [Bill.from_dict(y) for y in bills.get("bills")]
         _meta = Meta.from_dict(bills.get("meta"))
@@ -308,7 +366,7 @@ class BillFile:
     type: str
 
     @staticmethod
-    def from_dict(bill_file_data: dict) -> 'BillFile':
+    def from_dict(bill_file_data: dict) -> "BillFile":
         bill_file = bill_file_data.get("data")
         _file_base64 = str(bill_file.get("file_base64"))
         _file_name = str(bill_file.get("file_name"))
@@ -323,7 +381,7 @@ class Range:
     start_date: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Range':
+    def from_dict(obj: Any) -> "Range":
         _end_date = str(obj.get("end_date"))
         _start_date = str(obj.get("start_date"))
         return Range(_end_date, _start_date)
@@ -342,7 +400,7 @@ class UsageCharge:
     variable_rate_incl_gst: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'UsageCharge':
+    def from_dict(obj: Any) -> "UsageCharge":
         _end_date = str(obj.get("end_date"))
         _fixed_rate_incl_gst = str(obj.get("fixed_rate_incl_gst"))
         _hop_saving = str(obj.get("hop_saving"))
@@ -350,10 +408,21 @@ class UsageCharge:
         _supply_days = int(obj.get("supply_days"))
         _total_consumption = str(obj.get("total_consumption"))
         _total_fixed_charges_incl_gst = str(obj.get("total_fixed_charges_incl_gst"))
-        _total_variable_charges_incl_gst = str(obj.get("total_variable_charges_incl_gst"))
+        _total_variable_charges_incl_gst = str(
+            obj.get("total_variable_charges_incl_gst")
+        )
         _variable_rate_incl_gst = str(obj.get("variable_rate_incl_gst"))
-        return UsageCharge(_end_date, _fixed_rate_incl_gst, _hop_saving, _start_date, _supply_days, _total_consumption,
-                           _total_fixed_charges_incl_gst, _total_variable_charges_incl_gst, _variable_rate_incl_gst)
+        return UsageCharge(
+            _end_date,
+            _fixed_rate_incl_gst,
+            _hop_saving,
+            _start_date,
+            _supply_days,
+            _total_consumption,
+            _total_fixed_charges_incl_gst,
+            _total_variable_charges_incl_gst,
+            _variable_rate_incl_gst,
+        )
 
 
 @dataclass
@@ -363,16 +432,19 @@ class ConsumptionSummary:
     type: str
 
     @staticmethod
-    def from_dict(consumption_summary_data: Any) -> 'ConsumptionSummary':
+    def from_dict(consumption_summary_data: Any) -> "ConsumptionSummary":
         consumption_summary = consumption_summary_data.get("data")
         _range = Range.from_dict(consumption_summary.get("range"))
-        _usage_charges = [UsageCharge.from_dict(y) for y in consumption_summary.get("usage_charges")]
+        _usage_charges = [
+            UsageCharge.from_dict(y) for y in consumption_summary.get("usage_charges")
+        ]
         _type = str(consumption_summary.get("type"))
         return ConsumptionSummary(_range, _usage_charges, _type)
 
 
 # HOP
 
+
 @dataclass
 class Interval:
     consumption: str
@@ -380,7 +452,7 @@ class Interval:
     time: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Interval':
+    def from_dict(obj: Any) -> "Interval":
         _consumption = str(obj.get("consumption"))
         _hop_best = int(obj.get("hop_best"))
         _time = str(obj.get("time"))
@@ -405,26 +477,42 @@ class Usage:
     variable_charges_incl_gst: str
 
     @staticmethod
-    def from_dict(usage: dict) -> 'Usage':
+    def from_dict(usage: dict) -> "Usage":
         _adjustment_charges_incl_gst = str(usage.get("adjustment_charges_incl_gst"))
         _bill_consumption = str(usage.get("bill_consumption"))
         _consumption = str(usage.get("consumption"))
         _consumption_adjustment = str(usage.get("consumption_adjustment"))
         _fixed_charges_excl_gst = str(usage.get("fixed_charges_excl_gst"))
         _fixed_charges_incl_gst = str(usage.get("fixed_charges_incl_gst"))
-        _intervals = [{y: [Usage.from_dict(usage.get("intervals").get(y))]} for y in
-                      usage.get("usage").keys()]
-        _percent_consumption_adjustment = str(usage.get("percent_consumption_adjustment"))
+        _intervals = [
+            {y: [Usage.from_dict(usage.get("intervals").get(y))]}
+            for y in usage.get("usage").keys()
+        ]
+        _percent_consumption_adjustment = str(
+            usage.get("percent_consumption_adjustment")
+        )
         _range = Range.from_dict(usage.get("range"))
         _status = str(usage.get("status"))
         _total_charges_incl_gst = str(usage.get("total_charges_incl_gst"))
         _type = str(usage.get("type"))
         _variable_charges_excl_gst = str(usage.get("variable_charges_excl_gst"))
         _variable_charges_incl_gst = str(usage.get("variable_charges_incl_gst"))
-        return Usage(_adjustment_charges_incl_gst, _bill_consumption, _consumption, _consumption_adjustment,
-                     _fixed_charges_excl_gst, _fixed_charges_incl_gst, _intervals, _percent_consumption_adjustment,
-                     _range, _status, _total_charges_incl_gst, _type, _variable_charges_excl_gst,
-                     _variable_charges_incl_gst)
+        return Usage(
+            _adjustment_charges_incl_gst,
+            _bill_consumption,
+            _consumption,
+            _consumption_adjustment,
+            _fixed_charges_excl_gst,
+            _fixed_charges_incl_gst,
+            _intervals,
+            _percent_consumption_adjustment,
+            _range,
+            _status,
+            _total_charges_incl_gst,
+            _type,
+            _variable_charges_excl_gst,
+            _variable_charges_incl_gst,
+        )
 
 
 @dataclass
@@ -434,7 +522,7 @@ class Range:
     group_by: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Range':
+    def from_dict(obj: Any) -> "Range":
         _end_date = str(obj.get("end_date"))
         _start_date = str(obj.get("start_date"))
         _group_by = str(obj.get("group_by"))
@@ -449,13 +537,15 @@ class ConsumptionAverage:
     usage: List[dict]
 
     @staticmethod
-    def from_dict(consumption_average_data: dict) -> 'ConsumptionAverage':
+    def from_dict(consumption_average_data: dict) -> "ConsumptionAverage":
         consumption_average = consumption_average_data.get("data")
         _group_breakdown = consumption_average.get("group_breakdown")
         _range = Range.from_dict(consumption_average.get("range"))
         _type = str(consumption_average.get("type"))
-        _usage = [{y: [Usage.from_dict(consumption_average.get("usage").get(y))]} for y in
-                  consumption_average.get("usage").keys()]
+        _usage = [
+            {y: [Usage.from_dict(consumption_average.get("usage").get(y))]}
+            for y in consumption_average.get("usage").keys()
+        ]
         return ConsumptionAverage(_group_breakdown, _range, _type, _usage)
 
 
@@ -466,7 +556,7 @@ class HopInterval:
     start_time: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'HopInterval':
+    def from_dict(obj: Any) -> "HopInterval":
         _active = int(obj.get("active"))
         _end_time = str(obj.get("end_time"))
         _start_time = str(obj.get("start_time"))
@@ -477,15 +567,19 @@ class HopInterval:
 class HopIntervals:
     hop_duration: str
     type: str
-    intervals: List[dict]
+    intervals: OrderedDict[int, HopInterval]
 
     @staticmethod
-    def from_dict(hop_intervals_data: Any) -> 'HopIntervals':
+    def from_dict(hop_intervals_data: Any) -> "HopIntervals":
         hop_intervals = hop_intervals_data.get("data")
         _hop_duration = str(hop_intervals.get("hop_duration"))
         _type = str(hop_intervals.get("type"))
-        _intervals = [{y: [HopInterval.from_dict(hop_intervals.get("intervals").get(y))]} for y in
-                      hop_intervals.get("intervals").keys()]
+        _intervals = OrderedDict()
+        for y in hop_intervals.get("intervals").keys():
+            _intervals[int(y)] = HopInterval.from_dict(
+                hop_intervals.get("intervals").get(y)
+            )
+        _intervals = OrderedDict(sorted(_intervals.items()))
         return HopIntervals(_hop_duration, _type, _intervals)
 
 
@@ -495,7 +589,7 @@ class End:
     interval: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'End':
+    def from_dict(obj: Any) -> "End":
         _end_time = str(obj.get("end_time"))
         _interval = str(obj.get("interval"))
         return End(_end_time, _interval)
@@ -507,7 +601,7 @@ class Start:
     interval: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Start':
+    def from_dict(obj: Any) -> "Start":
         _start_time = str(obj.get("start_time"))
         _interval = str(obj.get("interval"))
         return Start(_start_time, _interval)
@@ -522,7 +616,7 @@ class Hop:
     type: str
 
     @staticmethod
-    def from_dict(hop_data: Any) -> 'Hop':
+    def from_dict(hop_data: Any) -> "Hop":
         hop = hop_data.get("data")
         _connection_id = str(hop.get("connection_id"))
         _customer_number = int(hop.get("customer_number"))
@@ -539,7 +633,7 @@ class Connection:
     connection_id: int
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Connection':
+    def from_dict(obj: Any) -> "Connection":
         _address = str(obj.get("address"))
         _identifier = str(obj.get("identifier"))
         _connection_id = int(obj.get("connection_id"))
@@ -552,7 +646,7 @@ class Subscriptions:
     stay_ahead: str
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Subscriptions':
+    def from_dict(obj: Any) -> "Subscriptions":
         _bill_alert = str(obj.get("bill_alert"))
         _stay_ahead = str(obj.get("stay_ahead"))
         return Subscriptions(_bill_alert, _stay_ahead)
@@ -569,7 +663,7 @@ class SessionCustomer:
     subscriptions: Subscriptions
 
     @staticmethod
-    def from_dict(customer: Any) -> 'SessionCustomer':
+    def from_dict(customer: Any) -> "SessionCustomer":
         _connection = Connection.from_dict(customer.get("connection"))
         _customer_number = int(customer.get("customer_number"))
         _email = str(customer.get("email"))
@@ -577,8 +671,15 @@ class SessionCustomer:
         _last_name = str(customer.get("last_name"))
         _is_active = str(customer.get("is_active"))
         _subscriptions = Subscriptions.from_dict(customer.get("subscriptions"))
-        return SessionCustomer(_connection, _customer_number, _email, _first_name, _last_name, _is_active, _subscriptions)
-
+        return SessionCustomer(
+            _connection,
+            _customer_number,
+            _email,
+            _first_name,
+            _last_name,
+            _is_active,
+            _subscriptions,
+        )
 
 
 @dataclass
@@ -588,7 +689,7 @@ class Session:
     type: str
 
     @staticmethod
-    def from_dict(session_data: Any) -> 'Session':
+    def from_dict(session_data: Any) -> "Session":
         session = session_data.get("data")
         _customer = [SessionCustomer.from_dict(y) for y in session.get("customer")]
         _customer_numbers = session.get("customer_numbers")
@@ -605,7 +706,7 @@ class OutageContact:
     type: str
 
     @staticmethod
-    def from_dict(outage_contact_data: Any) -> 'OutageContact':
+    def from_dict(outage_contact_data: Any) -> "OutageContact":
         outage_contact = outage_contact_data.get("data")
         _message = str(outage_contact.get("message"))
         _network_name = str(outage_contact.get("network_name"))
